@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Bcrypt;
@@ -69,7 +69,7 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Bcrypt - Crypt::Passphrase::Bcryp
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -87,9 +87,11 @@ version 0.0103
 
   # In your program:
 
-  my ($c, $user, $pass) = @_;
-  my $result = $c->schema->resultset('Account')->search({ user => $user })->first;
-  return 1 if $result && $result->check_password($pass);
+  my ($self, $user, $pass) = @_;
+  my $result = $self->schema->resultset('Account')
+    ->search({ user => $user })->first;
+  return 1
+    if $result && $result->check_password($pass);
 
 =head1 DESCRIPTION
 
@@ -100,27 +102,32 @@ Use L<Crypt::Passphrase::Bcrypt> for an encoded password column.
 =head2 cost
 
 A single or double digit non-negative integer representing the cost of the
-hash function. Defaults to C<8>.
+hash function.
+
+Default: C<8>
 
 =head1 METHODS
 
 =head2 make_encode_sub
 
-  my $result = $c->schema->resultset('Account')->create({ user => $user, password => $pass });
+Return a coderef that accepts a plain text value and returns an encoded value.
+This routine is used internally, to encrypt a given plain text password.
 
-Returns a coderef that accepts a plain text value and returns an encoded value.
-This routine is used internally, to encrypt the given plain text password.
+  $result = $self->schema->resultset('Account')
+    ->create({ user => $user, password => $pass });
 
 =head2 make_check_sub
 
-  $result->check_password($pass);
-
-Returns a coderef that when given the row object and a plain text value will
+Return a coderef that, when given a resultset object and a plain text value, will
 return a boolean if the plain text matches the encoded value. This is typically
 used for password authentication.
 
+  $result->check_password($pass);
+
 =head1 SEE ALSO
 
+The F<t/01-methods.t> file
+
 L<Crypt::Passphrase>
 
 L<DBIx::Class::EncodedColumn>
